hstrat.hstrat.stratum\_retention\_predicates.StratumRetentionPredicateDepthProportionalResolution
=================================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_predicates

.. autoclass:: StratumRetentionPredicateDepthProportionalResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionPredicateDepthProportionalResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionPredicateDepthProportionalResolution.CalcNumStrataRetainedExact
      ~StratumRetentionPredicateDepthProportionalResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionPredicateDepthProportionalResolution.CalcRankAtColumnIndex
      ~StratumRetentionPredicateDepthProportionalResolution.__init__
   
   

   
   
   